@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: urls.py 11517 2019-05-03 12:53:40Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,11 +11,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Andy $
+# $Date: 2019-05-03 20:53:40 +0800 (Fri, 03 May 2019) $
+# $Revision: 11517 $
 
-from django.conf.urls import patterns
 from django.conf.urls import include, url
 # Required import for 404 handle.
 from django.conf.urls import handler404
@@ -26,14 +25,18 @@ from django.views.generic.base import TemplateView as direct_to_template
 from django.contrib import admin
 admin.autodiscover()
 
+from Iuno.Patch import patterns
+
 from . import settings
 
 urlpatterns = patterns('')
 
 import Iuno
-Iuno.attachUrls(settings, urlpatterns)
+Iuno.attachURLs(settings, urlpatterns)
 
 urlpatterns += patterns('',
     (r'^i18n/', include('Iuppiter.i18n.urls')),
     (r'^admin/', include(admin.site.urls)),
 )
+
+
