@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 11632 2019-06-11 20:30:52Z Lavender $
+# $Id: Patch.py 12048 2020-04-06 10:51:25Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2019-06-12 05:30:52 +0900 (週三, 12 六月 2019) $
-# $Revision: 11632 $
+# $Author: Trista $ (last)
+# $Date: 2020-04-06 18:51:25 +0800 (Mon, 06 Apr 2020) $
+# $Revision: 12048 $
 #
 # Contributors:
 #  Bear
@@ -209,11 +209,19 @@ def attachURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
+    from functools import partial
+
+    from django.views.decorators.csrf import csrf_exempt
     from django.conf.urls import url, include
     from des import urls as des_urls
 
+    from Iuno.cloud.logging.views import sendLog
+
     urlpatterns += patterns('',
         url(r'^django-des/', include(des_urls)),
+        url(r'^log/', csrf_exempt(partial(sendLog,
+            title=settings.APP_NAME if hasattr(settings, 'APP_NAME') else '')),
+            name='sendLog'),
     )
     
     addMetricsUrl = False
