@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12020 2020-03-26 11:24:20Z Trista $
+# $Id: __init__.py 12069 2020-04-12 10:17:18Z Becca $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2020-03-26 19:24:20 +0800 (週四, 26 三月 2020) $
-# $Revision: 12020 $
+# $Author: Becca $ (last)
+# $Date: 2020-04-12 18:17:18 +0800 (Sun, 12 Apr 2020) $
+# $Revision: 12069 $
 
 from __future__ import print_function
 
@@ -508,7 +508,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         # timezone as the operating system.
         # If running in a Windows environment this must be set to the same as 
         # your system time zone.
-        'TIME_ZONE': ('Asia/Taipei' if sys.platform.startswith('win')
+        'TIME_ZONE': ('Asia/Taipei' if (sys.platform.startswith('win') or 
+                                        sys.platform.startswith('darwin'))
                                     else None),
         'LANGUAGE_CODE': 'en-us',
         'USE_I18N': True,
@@ -525,7 +526,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     }
     
     if (DJANGO_VERSION >= 11100 and 
-        not sys.platform.startswith('win')): # django >= 1.11
+        (not sys.platform.startswith('win') or 
+        not sys.platform.startswith('darwin'))): # django >= 1.11
         i18nDefaults['TIME_ZONE'] = 'UTC'
     
     update(settingsDict, i18nDefaults)
