@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11731 2019-10-02 16:41:15Z Lavender $
+# $Id: __init__.py 11859 2020-01-12 11:48:41Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-10-03 01:41:15 +0900 (週四, 03 十月 2019) $
-# $Revision: 11731 $
+# $Date: 2020-01-12 19:48:41 +0800 (Sun, 12 Jan 2020) $
+# $Revision: 11859 $
 #
 # Contributors:
 #  Bear (original author)
@@ -38,16 +38,20 @@ def attachSettings(settingsLocals, backends, preferred, config):
         'Iuno.cloud.metrics',
     ))
     
-    extendMiddlewareClasses(settingsLocals, [
-        'django_statsd.middleware.StatsdMiddleware',
-        ], 
-        key='django.contrib.sessions.middleware.SessionMiddleware', 
-        addBefore=True
-    )
+    # https://code.nuwainfo.com/trac/Mercurius/ticket/3302#ticket
+    # 先註解移掉
+    # extendMiddlewareClasses(
+        # settingsLocals, 
+        # [
+            # 'django_statsd.middleware.StatsdMiddleware',
+        # ], 
+        # key='django.contrib.sessions.middleware.SessionMiddleware', 
+        # addBefore=True
+    # )
     
-    extendMiddlewareClasses(settingsLocals, [
-        'django_statsd.middleware.StatsdMiddlewareTimer',
-    ])
+    # extendMiddlewareClasses(settingsLocals, [
+        # 'django_statsd.middleware.StatsdMiddlewareTimer',
+    # ])
     
     DEFAULT_STATSD_SETTINGS = {
         'STATSD_HOST': config.get("host", "statsd.nuwainfo.com"),
