@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12048 2020-04-06 10:51:25Z Trista $
+# $Id: __init__.py 12067 2020-04-11 14:38:53Z Trista $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-04-06 18:51:25 +0800 (週一, 06 四月 2020) $
-# $Revision: 12048 $
+# $Date: 2020-04-11 22:38:53 +0800 (Sat, 11 Apr 2020) $
+# $Revision: 12067 $
 
 import os
 import sys
@@ -497,8 +497,8 @@ def attachSettings(settingsDict, enablePaypal=False):
 
     if not hasConfig:
         
-        language_code = settingsDict['LANGUAGE_CODE'] if 'LANGUAGE_CODE' in settingsDict else 'en'
-        if (language_code == 'zh-hant') or (language_code == 'zh') or (language_code == 'zh-hans'):
+        languageCode = settingsDict.get('LANGUAGE_CODE', 'en') 
+        if (languageCode == 'zh-hant') or (languageCode == 'zh') or (languageCode == 'zh-hans'):
             if needShipping:
                 ADDING_OSCAR_ORDER_STATUS = {
                     'OSCAR_PROCESSING_SEND_EMAIL_STATUS': u'商品送貨中',
