@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12017 2020-03-26 05:57:40Z Lavender $
+# $Id: views.py 12046 2020-04-05 12:13:56Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-26 14:57:40 +0900 (週四, 26 三月 2020) $
-# $Revision: 12017 $ 
+# $Date: 2020-04-05 20:13:56 +0800 (Sun, 05 Apr 2020) $
+# $Revision: 12046 $ 
 
 import json
 import logging
@@ -750,13 +750,20 @@ def updateRecord(request, *args, **kwargs):
     pk = int(kwargs['pk'])
     recordId = int(kwargs['recordId'])
     date = request.POST.get("expiredTime", None)
-    print(date)
     record = BonusRecord.objects.get(id=recordId)
-    record.expiredTimeSetting = date
-    record.save()
     
-    messages.info(
-        request, _("Update success"))
+    try:
+        if date:
+            record.expireTimeSetting = date
+        else:
+            record.expireTimeSetting = None
+        record.save()
+        
+        messages.info(
+            request, _("Update success"))
+    except Exception as e:
+        messages.error(
+            request, _("Wrong date format, the correct format must be YYYY-MM-DD."))
         
     return redirect(reverse("dashboard:user-detail", kwargs={'pk': pk,}))
     
