@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11953 2020-02-25 08:39:42Z Lavender $
+# $Id: admin.py 11965 2020-03-05 11:53:49Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-25 17:39:42 +0900 (週二, 25 二月 2020) $
-# $Revision: 11953 $
+# $Date: 2020-03-05 19:53:49 +0800 (Thu, 05 Mar 2020) $
+# $Revision: 11965 $
 
 import os
 import datetime
@@ -386,8 +386,16 @@ class BaseFileAdmin(admin.ModelAdmin):
         # reload loader
         for engine in engines.all():
             for loader in engine.engine.template_loaders:
-                loader.reset()
-
+                if (hasattr(loader, 'template_cache') and hasattr(loader, 'find_template_cache') 
+                    and hasattr(loader, 'get_template_cache')):
+                    # for cache loader
+                    key = loader.cache_key(obj.path, None)
+                    loader.template_cache.pop(key, None)
+                    loader.find_template_cache.pop(key, None)
+                    loader.get_template_cache.pop(key, None)
+                else:
+                    loader.reset()
+        
         return super(BaseFileAdmin, self).response_change(request, obj)
 
     def changelist_view(self, request, extra_context=None):
